@@ -1,17 +1,8 @@
 activity_frequency_trace <- function(eventlog) {
-
-	stop_eventlog(eventlog)
-
-	cases <- cases_light(eventlog)
-
+	cases <- case_list(eventlog)
 	eventlog %>%
 		activity_frequency_case() %>%
 		merge(cases) %>%
-		select(trace, absolute, relative) %>%
-		unique -> r
-
-
-	return(r)
-
-
+		select(4,2,3) %>%
+		unique
 }
