@@ -1,16 +1,15 @@
 
 end_activities_resource_activity <- function(eventlog) {
-
+	absolute <- NULL
+	relative <- NULL
 	eventlog %>%
-		group_by(!!as.symbol(case_id(eventlog))) %>%
-		mutate(rank = row_number(desc(!!as.symbol(timestamp(eventlog))))) %>%
-		filter(rank == 1) %>%
+		group_by_case() %>%
+		summarize(!!as.symbol(activity_id(eventlog)) := last(!!as.symbol(activity_id(eventlog))),
+				  !!as.symbol(resource_id(eventlog)) := last(!!as.symbol(resource_id(eventlog)))) %>%
 		group_by(!!as.symbol(resource_id(eventlog)), !!as.symbol(activity_id(eventlog))) %>%
 		summarize(absolute = n()) %>%
 		ungroup() %>%
 		arrange(desc(absolute)) %>%
 		mutate(relative = absolute/n_cases(eventlog),
-			   cum_sum = cumsum(relative)) %>%
-	return()
-
+			   cum_sum = cumsum(relative))
 }
