@@ -1,15 +1,26 @@
-#' @title Referral matric selfloops
+#' @title Referral matrix selfloops
 #'
 #' @description Provides a list of initatiors and completers of  redo selfloops
 #'
-#' @param eventlog The event log to be used. An object of class
-#' \code{eventlog}.
-#'
-#'
-#'
-#' @export redo_selfloops_referral_matrix
 
+#' @inherit activity_frequency params references seealso return
+
+#' @seealso \code{\link{number_of_selfloops}}
+
+#'
+#' @export
+#'
 redo_selfloops_referral_matrix <- function(eventlog) {
+	UseMethod("redo_selfloops_referral_matrix")
+}
+
+#' @describeIn redo_selfloops_referral_matrix Compute matrix for eventlog
+#' @export
+
+redo_selfloops_referral_matrix.eventlog <- function(eventlog) {
+	first_resource <- NULL
+	last_resource <- NULL
+
 	eventlog %>%
 		redo_selfloops() %>%
 		group_by(first_resource, last_resource) %>%
