@@ -1,11 +1,12 @@
 
 start_activities_resource <- function(eventlog) {
+	absolute <- NULL
+	relative <- NULL
 
 	eventlog %>%
-		group_by(!!as.symbol(case_id(eventlog))) %>%
-		mutate(rank = row_number(!!as.symbol(timestamp(eventlog)))) %>%
-		filter(rank == 1) %>%
-		group_by(!!as.symbol(resource_id(eventlog))) %>%
+		group_by_case %>%
+		mutate(row_number(!!timestamp_(eventlog))==1) %>%
+		group_by_resource %>%
 		summarize(absolute = n()) %>%
 		arrange(desc(absolute)) %>%
 		mutate(relative = absolute/n_cases(eventlog),
