@@ -1,12 +1,15 @@
 
 trace_coverage_trace <- function(eventlog) {
 
-	tr <- traces(eventlog)
+	absolute_frequency <- NULL
+	relative_frequency <- NULL
+	absolute <- NULL
+	relative <- NULL
 
-	tr <- tr %>%
+	eventlog %>%
+		traces %>%
 		select(trace, absolute = absolute_frequency, relative = relative_frequency) %>%
 		arrange(desc(absolute)) %>%
 		mutate(cum_sum = cumsum(relative))
 
-	return(tr)
 }
